@@ -44,17 +44,9 @@ BcdClockWidget::BcdClockWidget(QWidget *parent) :
     layout->setSizeConstraint(QLayout::SetMinimumSize);
 
     updateTime();
-
-    timer = new QTimer();
-    timer->setInterval(1000);
-    connect(timer, SIGNAL(timeout()), this, SLOT(updateTime()));
-    timer->start();
 }
 
 BcdClockWidget::~BcdClockWidget(){
-    timer->stop();
-    delete timer;
-
     delete secondsOneWidget;
     delete secondsTenWidget;
     delete minutesOneWidget;
