@@ -21,7 +21,6 @@
 #define BCDCLOCKWIDGET_H
 
 #include <QHBoxLayout>
-#include <QTimer>
 
 #include "clockwidget.h"
 #include "verticalbinarydisplaywidget.h"
@@ -39,12 +38,11 @@ public:
     void setLedColor(const QColor &color);
     QSize sizeHint();
 
-private slots:
+protected slots:
     void updateTime();
 
 private:
     QHBoxLayout *layout;
-    QTimer *timer;
 
     VerticalBinaryDisplayWidget *secondsOneWidget;
     VerticalBinaryDisplayWidget *secondsTenWidget;
