@@ -38,17 +38,9 @@ BinaryClockWidget::BinaryClockWidget(QWidget *parent) :
     layout->setSizeConstraint(QLayout::SetMinimumSize);
 
     updateTime();
-
-    timer = new QTimer();
-    timer->setInterval(1000);
-    connect(timer, SIGNAL(timeout()), this, SLOT(updateTime()));
-    timer->start();
 }
 
 BinaryClockWidget::~BinaryClockWidget(){
-    timer->stop();
-    delete timer;
-
     delete secondsWidget;
     delete minutesWidget;
     delete hoursWidget;
