@@ -21,7 +21,6 @@
 #define BINARYCLOCKWIDGET_H
 
 #include <QVBoxLayout>
-#include <QTimer>
 
 #include "clockwidget.h"
 #include "horizontalbinarydisplaywidget.h"
@@ -45,7 +44,6 @@ private slots:
 
 private:
     QVBoxLayout *layout;
-    QTimer *timer;
 
     HorizontalBinaryDisplayWidget *secondsWidget;
     HorizontalBinaryDisplayWidget *minutesWidget;
