@@ -22,4 +22,22 @@
 ClockWidget::ClockWidget(QWidget *parent) :
     QWidget(parent)
 {
+    timer = new QTimer();
+    connect(timer, SIGNAL(timeout()), this, SLOT(updateTime()));
+    timer->start(1000);
+}
+
+ClockWidget::~ClockWidget(){
+    timer->stop();
+    disconnect(timer, SIGNAL(timeout()), this, SLOT(updateTime()));
+    delete timer;
+}
+
+void ClockWidget::resumeClock(bool resume){
+    if(resume){
+        updateTime();
+        timer->start(1000);
+    }else{
+        timer->stop();
+    }
 }
