@@ -22,6 +22,7 @@
 
 #include <QColor>
 #include <QSize>
+#include <QTimer>
 #include <QWidget>
 
 #include <QMouseEvent>
@@ -32,12 +33,22 @@ class ClockWidget : public QWidget
 
 public:
     explicit ClockWidget(QWidget *parent = 0);
+    ~ClockWidget();
 
     virtual void setLedSize(int size) = 0;
     virtual void setLedBorder(int border) = 0;
     virtual void setLedColor(const QColor &color) = 0;
 
     virtual QSize sizeHint() = 0;
+
+public slots:
+    void resumeClock(bool pause);
+
+protected slots:
+    virtual void updateTime() = 0;
+
+private:
+    QTimer *timer;
 };
 
 #endif // CLOCKWIDGET_H
