@@ -26,7 +26,7 @@
 MainWidget::MainWidget(QWidget *parent) :
     QWidget(parent
 #ifndef Q_WS_MAEMO_5
-            , Qt::Window
+            , Qt::SplashScreen
             | Qt::FramelessWindowHint
 #endif
             )
@@ -45,18 +45,16 @@ MainWidget::MainWidget(QWidget *parent) :
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_TranslucentBackground);
 #else
+    setAttribute(Qt::WA_DeleteOnClose);
     QSettings settings;
     move(settings.value(SettingsDialog::POSITION,
                         SettingsDialog::POSITION_DEFAULT).toPoint());
+    createMenu();
 #endif
 
     applySettings();
 
     layout->addWidget(clockWidget);
-
-#ifndef Q_WS_MAEMO_5
-    createMenu();
-#endif
 }
 
 MainWidget::~MainWidget(){
@@ -150,6 +148,7 @@ void MainWidget::mousePressEvent(QMouseEvent *event){
 
 void MainWidget::openSettingsDialog(){
     SettingsDialog dialog;
+    dialog.setAttribute(Qt::WA_QuitOnClose, false);
 
     if(dialog.exec()){
         applySettings();
@@ -179,6 +178,7 @@ void MainWidget::paintEvent(QPaintEvent */*event*/){
 
 void MainWidget::setClock(int clockStyle){
     if(clockWidget != NULL){
+        disconnect(this, SIGNAL(resumeClock(bool)), clockWidget, SLOT(resumeClock(bool)));
         delete clockWidget;
     }
 
@@ -194,6 +194,7 @@ void MainWidget::setClock(int clockStyle){
         break;
     }
 
+    connect(this, SIGNAL(resumeClock(bool)), clockWidget, SLOT(resumeClock(bool)));
     setFixedSize(clockWidget->sizeHint());
     layout->addWidget(clockWidget);
 }
